Drop Shadow Frame (dropshadow)

# Drop Shadow Frame (`dropshadow`)

## Drop Shadow Frame

A widget providing a drop shadow (gaussian blur effect) around another widget.

class `orangecanvas.gui.dropshadow.` `DropShadowFrame`(parent=None, color=None, radius=5, **kwargs)

  Bases: `PyQt5.QtWidgets.QWidget`

  A widget drawing a drop shadow effect around the geometry of another widget (works similar to `QFocusFrame`).

  Parameters: | parent (`QObject`) – Parent object. color (`QColor`) – The color of the drop shadow. radius (float) – Shadow radius.

  `setColor`(color)

    Set the color of the shadow.

  `color`()

    Return the color of the drop shadow.

  `color_`

    Drop shadow color

  `setRadius`(radius)

    Set the drop shadow’s blur radius.

  `radius`()

    Return the shadow blur radius.

  `radius_`

    Drop shadow blur radius.

  `setWidget`(widget)

    Set the widget around which to show the shadow.

  `widget`()

    Return the widget that was set by setWidget.